# graphtransformer
This is a package and cleaner version of the digress (https://arxiv.org/abs/2209.14734) graph transformer

This architecture seems to be particulary good to handle graphs and doing graph generation.
